//
//  The IMAGERESOLVER Class
//
// Although Javascript does not support private members, you shouldn't
// access any of the member variables.  Instead, you should use the
// methods provided.
//
// getUrl(feedName)
//    this will translate the feed name (e.g., '05c.bmp')
//    into the proper URL for that image.  Sometimes, this will be a
//    chrome:// url for those images that are distributed with the distribution
//    and other times, it will be an http:// url
//
// $Id: class_ImageResolver.js,v 1.7 2004/10/20 18:21:59 dviner Exp $

function ImageResolver()
{
    this.debug = false;
    this.defaultYahooBase = "http://us.i1.yimg.com/us.yimg.com/i/tb/iconsgif/";
    this.map = new Object();
    // add a whole bunch of stuff now
    this.init();
}

ImageResolver.prototype.getUrl = function(pszFeedImageName)
{
    if(typeof this.map[pszFeedImageName] == "undefined")
    {
        // we don't have this one..
        // so use our default
        pszFeedImageName = pszFeedImageName.replace(/\.bmp/,".gif");
        return this.defaultYahooBase + pszFeedImageName;
    }
    else
    {
        // we have one...
        return this.map[pszFeedImageName];
    }
}


ImageResolver.prototype.addMapping = function(pszFeedName,pszRealUrl)
{
    this.map[pszFeedName] = pszRealUrl;
}

ImageResolver.prototype.init = function()
{
    // probably call readZipFile
    var rv = this.readZip();
    
    if(!rv)
    {
        if(this.debug)
            alert("failed in reading zip.. use defaults");
        this.assignDefaults();
    }
    // the Mail notification bell
    this.addMapping("alert","chrome://yahootoolbar/content/icons/bell.gif");
    // the Y logo
    this.addMapping("logo","chrome://yahootoolbar/content/icons/y.gif");
    // the options menu
    this.addMapping("option","chrome://yahootoolbar/content/icons/setti.gif");
    // the search magnifying glass
    this.addMapping("stoggle","chrome://yahootoolbar/content/icons/mglass.gif");
    // vertical separator
    this.addMapping("vsep","");
}

ImageResolver.prototype.readZip = function ()
{
    /*
      See this source
      http://lxr.mozilla.org/aviarybranch/source/toolkit/mozapps/extensions/src/nsExtensionManager.js.in
    */
    try {
        var pszZipFile = this.getZipFile();
    }
    catch(ex) {
        return false;
    }

    // convert string to nsIFile
    var cFile = this.getFileFromURL(pszZipFile);
    if(cFile == null)
        return false;
    
    var zip = Components.classes["@mozilla.org/libjar/zip-reader;1"]
                   .createInstance(Components.interfaces.nsIZipReader);
    if(this.debug)
        alert('got zip file interface');
    
    zip.init(cFile);
    //alert('opening zip file');
    zip.open();
    //alert('getting entries');
    var entries = zip.findEntries("*.gif");
    while (entries.hasMoreElements())
    {
        var entry = entries.getNext().QueryInterface(Components.interfaces.nsIZipEntry);
        
        // entry.name is something like 'content/icons/18c.gif'
        // now we need to add the mapping from
        // '18c.bmp' to 'chrome://yahootoolbar/content/icons/18c.gif'
        var pszBmpName = this.convertToBmp(entry.name);
        
        if(this.debug)
            alert("got entry: '" + entry.name+"'\nmade: '" +pszBmpName+"'");
        
        this.addMapping(pszBmpName,"chrome://yahootoolbar/"+entry.name);
    }
    if(this.debug)
        alert('closing zip');
    zip.close();
    
    return true;
}

ImageResolver.prototype.convertToBmp = function (pszGifName)
{
    // pszGifName is something like 'content/icons/18c.gif'
    var iLastSlash = pszGifName.lastIndexOf("/");
    iLastSlash++;
    var pszBmpName = pszGifName.substr(iLastSlash);
    pszBmpName = pszBmpName.replace(/\.gif/,".bmp");
    //alert("BMP name now is: " + pszBmpName);
    return pszBmpName;
}

ImageResolver.prototype.getFileFromURL = function(pszFile)
{
    var ioServ = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
    
    var pszNewFile = pszFile.replace(/^.*file:/,"file:");
    if(this.debug)
        alert('Built file name: ' + pszNewFile);
    
    var aFile = null;
    try
    {
        var fph = ioServ.getProtocolHandler("file").QueryInterface(Components.interfaces.nsIFileProtocolHandler);
        aFile = fph.getFileFromURLSpec(pszNewFile);
    }
    catch(e)
    {
        if(this.debug)
            alert('failed...');
    }
    if(this.debug)
        alert('built nsIFile: ' + aFile);
   
    if(aFile != null)
        return aFile;
    // FireFox will return here...
    
    // for Mozilla

    // now reduce the pszFile to the jar file itself
    var iLastSlash = pszNewFile.lastIndexOf("/");
    iLastSlash++;
    var pszJarFileOnly = pszNewFile.substr(iLastSlash);
    // try this... instead
    /*
    var rph = ioServ.getProtocolHandler("res").QueryInterface(Components.interfaces.nsIFileProtocolHandler);
    var bFile = rph.getFileFromURLSpec(pszNewFile);

    alert("build from res: " + bFile);
    return bFile;
    */
    // first get the user chrome dir
    var dirServ = Components.classes['@mozilla.org/file/directory_service;1'].createInstance();
    dirServ = dirServ.QueryInterface(Components.interfaces.nsIProperties);
    var chromeDir = dirServ.get("UChrm", Components.interfaces.nsIFile);
    chromeDir.append(pszJarFileOnly);
    
    if(this.debug)
        alert("chromeDir now is: " + chromeDir + "\npath: " + chromeDir.path);
    // see if this file exists
    if(chromeDir.exists())
    {
        if(this.debug)
            alert("found it");
        return chromeDir;
    }
    
    var globalChromeDir = dirServ.get("AChrom", Components.interfaces.nsIFile);
    globalChromeDir.append(pszJarFileOnly);
    
    if(this.debug)
        alert("globalChromeDir now is: " + globalChromeDir + "\npath: " + globalChromeDir.path);
    // see if this file exists
    if(globalChromeDir.exists())
    {
        if(this.debug)
            alert("found it");
        return globalChromeDir;
    }
    if(this.debug)
        alert("Can't find any yahootoolbar.jar!");
    return null;
}

ImageResolver.prototype.getZipFile = function()
{
    var uri = Components.classes['@mozilla.org/network/simple-uri;1'].createInstance();
    uri = uri.QueryInterface(Components.interfaces.nsIURI);
    
    if(this.debug)
        alert('got simple uri');
    
    var cr = Components.classes['@mozilla.org/chrome/chrome-registry;1'].getService();
    cr.QueryInterface(Components.interfaces.nsIChromeRegistry);
    
    if(this.debug)
        alert('got chrome registry');
    
    uri.spec =  "chrome://yahootoolbar/content/icons/01c.gif";
    
    var rv= cr.convertChromeURL(uri);
    if (rv.path) rv  = rv.path;
 
    if(this.debug)
        alert("The Real url now is: \n"+rv.replace(/%20/g,"\n").replace(/%7B/g,"\n"));
    var pszJarFile = rv.replace(/!.*$/,"");
    if(this.debug)
        alert("The Real url now is: \n"+pszJarFile.replace(/%20/g,"\n").replace(/%7B/g,"\n"));
    return pszJarFile;
}

// this is used when we can't read the jar file for any reason.
ImageResolver.prototype.assignDefaults = function()
{
    //
    //   IMAGES WITH NUMERIC NAMES
    //    
    
    // the My Yahoo image
    this.addMapping("01c.bmp", "chrome://yahootoolbar/content/icons/01c.gif");

    // the Mail image
    this.addMapping("02c.bmp","chrome://yahootoolbar/content/icons/02c.gif");

    // the Calendar image
    this.addMapping("03c.bmp", "chrome://yahootoolbar/content/icons/03c.gif");

    // the Address Book image
    this.addMapping("04c.bmp", "chrome://yahootoolbar/content/icons/04c.gif");

    // the Mail image
    this.addMapping("05c.bmp", "chrome://yahootoolbar/content/icons/05c.gif");

    // unused
    this.addMapping("06c.bmp", "");
  
    // the News image
    this.addMapping("07c.bmp", "chrome://yahootoolbar/content/icons/07c.gif");

    // the Sports image
    this.addMapping("08c.bmp", "chrome://yahootoolbar/content/icons/08c.gif");

    // the Weather image
    this.addMapping("09c.bmp", "chrome://yahootoolbar/content/icons/09c.gif");

    // the Finance image
    this.addMapping("10c.bmp", "chrome://yahootoolbar/content/icons/10c.gif");

    // the Shopping image
    this.addMapping("11c.bmp", "chrome://yahootoolbar/content/icons/11c.gif");

    // the Movies image
    this.addMapping("16c.bmp", "chrome://yahootoolbar/content/icons/16c.gif");

    // the TV image
    this.addMapping("17c.bmp", "chrome://yahootoolbar/content/icons/17c.gif");

    // the Music image
    this.addMapping("18c.bmp", "chrome://yahootoolbar/content/icons/18c.gif");

    // the Games image
    this.addMapping("19c.bmp", "chrome://yahootoolbar/content/icons/19c.gif");

    // unused
    this.addMapping("23c.bmp", "");

    // the Yellow Pages image
    this.addMapping("25c.bmp", "chrome://yahootoolbar/content/icons/25c.gif");

    // the Maps image
    this.addMapping("27c.bmp", "chrome://yahootoolbar/content/icons/27c.gif");

    // the Travel image
    this.addMapping("30c.bmp", "chrome://yahootoolbar/content/icons/30c.gif");

    // the Briefcase image
    this.addMapping("36c.bmp", "chrome://yahootoolbar/content/icons/36c.gif");

    // the Mobile image
    this.addMapping("43c.bmp", "chrome://yahootoolbar/content/icons/43c.gif");

    // the Entertainment image
    this.addMapping("44c.bmp", "chrome://yahootoolbar/content/icons/44c.gif");

    // the Notepad image
    this.addMapping("46c.bmp", "chrome://yahootoolbar/content/icons/46c.gif");

    // the Logout image
    this.addMapping("48c.bmp", "chrome://yahootoolbar/content/icons/48c.gif");

    // the Messenger image
    this.addMapping("50c.bmp", "chrome://yahootoolbar/content/icons/50c.gif");

    // the Personals image
    this.addMapping("52c.bmp", "chrome://yahootoolbar/content/icons/52c.gif");

    // the Photos image
    this.addMapping("53c.bmp", "chrome://yahootoolbar/content/icons/53c.gif");

    // the Auctions image 
    this.addMapping("54c.bmp", "chrome://yahootoolbar/content/icons/54c.gif");

    //
    //   IMAGES WITH ALPHABETICAL NAMES
    //

    // the Ad Bigsales image 
    this.addMapping("ad_bigsale.bmp", "chrome://yahootoolbar/content/icons/ad_bigsale.gif");

    
    // the Horoscope image  
    this.addMapping("ar_59c.bmp", "chrome://yahootoolbar/content/icons/ar_59c.gif");
 
    // the CBB image  
    this.addMapping("cbb.bmp", "chrome://yahootoolbar/content/icons/cbb.gif");
    
    // the Yahoo! Folder image
    this.addMapping("dir.bmp", "chrome://yahootoolbar/content/icons/dir.gif");
 
    // the reference image
    this.addMapping("edu.bmp", "chrome://yahootoolbar/content/icons/edu.gif");
 
    // the Fifa image 
    this.addMapping("fifa2.bmp", "chrome://yahootoolbar/content/icons/fifa2.gif");
    
    // Finance images... not sure if these are right
    this.addMapping("fin_inv.bmp", "chrome://yahootoolbar/content/icons/fin_inv.gif");
    this.addMapping("fin_my.bmp", "chrome://yahootoolbar/content/icons/fin_my.gif");
    this.addMapping("fin_per.bmp", "chrome://yahootoolbar/content/icons/fin_per.gif");
    this.addMapping("fin_ref.bmp", "chrome://yahootoolbar/content/icons/fin_ref.gif");
    
    // the Yahoo! Groups image
    this.addMapping("grp.bmp", "chrome://yahootoolbar/content/icons/grp.gif");
 
    
    // the MLB  image 
    this.addMapping("mlb.bmp", "chrome://yahootoolbar/content/icons/mlb.gif");

    // the German Movies image  
    this.addMapping("mov_de.bmp", "chrome://yahootoolbar/content/icons/mov_de.gif");
 
    // the NFL image 
    this.addMapping("nfl.bmp", "chrome://yahootoolbar/content/icons/nfl.gif");

    // the NBA image  
    this.addMapping("nba.bmp", "chrome://yahootoolbar/content/icons/nba.gif");

    
    // the pub_s2 image 
    this.addMapping("pub_s2.bmp","chrome://yahootoolbar/content/icons/pub_s2.gif");

    // the qsbm image 
    this.addMapping("qsbm.bmp", "chrome://yahootoolbar/content/icons/qsbm.gif");

    // the qsim image 
    this.addMapping("qsim.bmp", "chrome://yahootoolbar/content/icons/qsim.gif");

    // the qsy image 
    this.addMapping("qsy.bmp", "chrome://yahootoolbar/content/icons/qsy.gif");

    // the qsyma image 
    this.addMapping("qsyma.bmp", "chrome://yahootoolbar/content/icons/qsyma.gif");

    // the Search Highlight image 
    this.addMapping("srch_hi.bmp", "chrome://yahootoolbar/content/icons/srch_hi.gif");

    
    
    // the SWI image 
    this.addMapping("swi.bmp", "chrome://yahootoolbar/content/icons/swi.gif");
 
    // the Search image  
    this.addMapping("tb_srch.bmp", "chrome://yahootoolbar/content/icons/tb_srch.gif");
  
    // the Y! image
    this.addMapping("tot.bmp","chrome://yahootoolbar/content/icons/tot.gif");
    
    // the Travel image (2nd)
    this.addMapping("tra.bmp", "chrome://yahootoolbar/content/icons/tra.gif");

    
    // new mail image
    this.addMapping("yma1.bmp", "chrome://yahootoolbar/content/icons/yma1.gif");

    // Translate image
    this.addMapping("xlt.bmp", "chrome://yahootoolbar/content/icons/xlt.gif");
}

